pub enum Error {
ReqwestError(Error),
ToStrError(ToStrError),
SelectorError(SelectorErrorKind<'static>),
ParseFloatError(ParseFloatError),
ParseIntError(ParseIntError),
MovieRatingError,
MovieYearError,
MovieNameError,
ParseError(String),
}Expand description
Variants
ReqwestError(Error)
Error originating from an HTTP request failure.
ToStrError(ToStrError)
Error converting HTTP header values to strings.
SelectorError(SelectorErrorKind<'static>)
Error parsing CSS selectors during HTML scraping.
ParseFloatError(ParseFloatError)
Error parsing a floating point number.
ParseIntError(ParseIntError)
Error parsing an integer.
MovieRatingError
Error indicating failure to extract the movie rating from HTML.
MovieYearError
Error indicating failure to extract the movie year from HTML.
MovieNameError
Error indicating failure to extract the movie name from HTML.
ParseError(String)
Error parsing an url.